import { AsyncPipe, NgClass } from '@angular/common';
import * as i0 from '@angular/core';
import { SecurityContext, Injectable, Component, NgModule } from '@angular/core';
import { DynamicFormElementBase, dynamicFormLibrary, withDynamicFormElements, importDynamicFormsProviders, DynamicFormConfigModule } from '@dynamic-forms/core';
import { of, from, BehaviorSubject } from 'rxjs';
import { map, switchMap } from 'rxjs/operators';
import { marked } from 'marked';
import * as i1 from '@angular/common/http';
import * as i2 from '@angular/platform-browser';

class MarkdownRenderer extends marked.Renderer {
    link(href, title, text) {
        const link = super.link(href, title, text);
        return link.replace('<a', '<a target="_blank"');
    }
}
class DynamicFormMarkdownService {
    constructor(httpClient, sanitizer) {
        this.httpClient = httpClient;
        this.sanitizer = sanitizer;
        marked.setOptions({ renderer: new MarkdownRenderer() });
    }
    compile(markdown, options) {
        const securityContext = this.getSecurityContext(options);
        return this.parseMarkdown(markdown).pipe(map(m => this.sanitizer.sanitize(securityContext, m)));
    }
    compileFromSource(source, options) {
        return this.httpClient.get(source, { responseType: 'text' }).pipe(switchMap(markdown => this.compile(markdown, options)));
    }
    parseMarkdown(markdown) {
        const parsedMarkdown = marked.parse(markdown);
        return typeof parsedMarkdown === 'string' ? of(parsedMarkdown) : from(parsedMarkdown);
    }
    getSecurityContext(options) {
        return options && !options.sanitize ? SecurityContext.NONE : SecurityContext.HTML;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.0.1", ngImport: i0, type: DynamicFormMarkdownService, deps: [{ token: i1.HttpClient }, { token: i2.DomSanitizer }], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.0.1", ngImport: i0, type: DynamicFormMarkdownService }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.0.1", ngImport: i0, type: DynamicFormMarkdownService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: i2.DomSanitizer }] });

class DynamicFormMarkdownComponent extends DynamicFormElementBase {
    constructor(markdownService) {
        super();
        this.markdownService = markdownService;
    }
    ngOnInit() {
        this._markdownSubject = new BehaviorSubject({
            source: this.template.source,
            markdown: this.template.markdown,
        });
        this.markdown$ = this._markdownSubject
            .asObservable()
            .pipe(switchMap(value => value.source
            ? this.markdownService.compileFromSource(value.source, this.definition.options)
            : this.markdownService.compile(value.markdown, this.definition.options)));
    }
    ngDoCheck() {
        const source = this.template.source;
        const markdown = this.template.markdown;
        if (this._markdownSubject.value.source !== source || this._markdownSubject.value.markdown !== markdown) {
            this._markdownSubject.next({ source, markdown });
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.0.1", ngImport: i0, type: DynamicFormMarkdownComponent, deps: [{ token: DynamicFormMarkdownService }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "18.0.1", type: DynamicFormMarkdownComponent, isStandalone: true, selector: "dynamic-form-markdown", usesInheritance: true, ngImport: i0, template: "<div class=\"dynamic-form-markdown\" [ngClass]=\"template.className\" [hidden]=\"hidden\" [innerHTML]=\"markdown$ | async\"></div>\n", dependencies: [{ kind: "pipe", type: AsyncPipe, name: "async" }, { kind: "directive", type: NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.0.1", ngImport: i0, type: DynamicFormMarkdownComponent, decorators: [{
            type: Component,
            args: [{ standalone: true, selector: 'dynamic-form-markdown', imports: [AsyncPipe, NgClass], template: "<div class=\"dynamic-form-markdown\" [ngClass]=\"template.className\" [hidden]=\"hidden\" [innerHTML]=\"markdown$ | async\"></div>\n" }]
        }], ctorParameters: () => [{ type: DynamicFormMarkdownService }] });

const dynamicFormMarkdownType = {
    type: 'markdown',
    component: DynamicFormMarkdownComponent,
    libraryName: dynamicFormLibrary.name,
};
function withDynamicFormsMarkdownFeatures() {
    const providers = [DynamicFormMarkdownService];
    return [{ providers }, withDynamicFormElements(dynamicFormMarkdownType)];
}
function provideDynamicFormsMarkdown() {
    return importDynamicFormsProviders(...withDynamicFormsMarkdownFeatures());
}
const modules = [DynamicFormConfigModule];
/**
 * @deprecated Use {@link provideDynamicFormsMarkdown} instead.
 */
class DynamicFormMarkdownModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.0.1", ngImport: i0, type: DynamicFormMarkdownModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "18.0.1", ngImport: i0, type: DynamicFormMarkdownModule, imports: [DynamicFormConfigModule], exports: [DynamicFormConfigModule] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "18.0.1", ngImport: i0, type: DynamicFormMarkdownModule, providers: provideDynamicFormsMarkdown(), imports: [modules, DynamicFormConfigModule] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.0.1", ngImport: i0, type: DynamicFormMarkdownModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: modules,
                    exports: modules,
                    providers: provideDynamicFormsMarkdown(),
                }]
        }] });

/*
 * Public API Surface of markdown
 */

/**
 * Generated bundle index. Do not edit.
 */

export { DynamicFormMarkdownComponent, DynamicFormMarkdownModule, DynamicFormMarkdownService, MarkdownRenderer, dynamicFormMarkdownType, provideDynamicFormsMarkdown, withDynamicFormsMarkdownFeatures };
//# sourceMappingURL=dynamic-forms-markdown.mjs.map
